@@ -358,9 +358,9 @@ api_str_coalesce(SEXP x){
 }
 
 SEXP
-api_reconstruct(SEXP x, SEXP source, bool shallow_copy){
+api_rebuild(SEXP x, SEXP source, bool shallow_copy){
   try {
-    return reconstruct(x, source, shallow_copy);
+    return rebuild(x, source, shallow_copy);
   } catch (...) {
     return R_NilValue;
   }
@@ -418,6 +418,6 @@ void api_init(DllInfo* dll){
   R_RegisterCCallable("cheapr", "api_df_assign_cols",    (DL_FUNC)api_df_assign_cols);
   R_RegisterCCallable("cheapr", "api_df_col_c",    (DL_FUNC)api_df_col_c);
   R_RegisterCCallable("cheapr", "api_str_coalesce",    (DL_FUNC)api_str_coalesce);
-  R_RegisterCCallable("cheapr", "api_reconstruct",    (DL_FUNC)api_reconstruct);
+  R_RegisterCCallable("cheapr", "api_rebuild",    (DL_FUNC)api_rebuild);
   R_RegisterCCallable("cheapr", "api_semi_copy",    (DL_FUNC)api_semi_copy);
 }
