@@ -6,7 +6,7 @@
 SEXP lag(SEXP x, R_xlen_t k, SEXP fill, bool set) {
   R_xlen_t size = Rf_xlength(x);
   R_xlen_t fill_size = Rf_xlength(fill);
-  int NP = 0;
+  int32_t NP = 0;
   if (fill_size > 1){
     Rf_error("fill size must be NULL or length 1");
   }
@@ -47,23 +47,23 @@ SEXP lag(SEXP x, R_xlen_t k, SEXP fill, bool set) {
   }
   case CHEAPR_INT64SXP: {
     k = k >= 0 ? std::min(size, k) : std::max(-size, k);
-    int_fast64_t fill_value = NA_INTEGER64;
+    int64_t fill_value = NA_INTEGER64;
     if (fill_size >= 1){
       SEXP temp_fill = SHIELD(coerce_vector(fill, CHEAPR_INT64SXP)); ++NP;
       fill_value = INTEGER64_PTR(temp_fill)[0];
     }
     out = SHIELD(set ? xvec : cpp_semi_copy(xvec)); ++NP;
-    int_fast64_t* RESTRICT p_out = INTEGER64_PTR(out);
-    int_fast64_t *p_x = INTEGER64_PTR(xvec);
+    int64_t* RESTRICT p_out = INTEGER64_PTR(out);
+    int64_t *p_x = INTEGER64_PTR(xvec);
 
-    // sizeof(int_fast64_t) == sizeof(double), both are 8 bytes
+    // sizeof(int64_t) == sizeof(double), both are 8 bytes
 
     if (k >= 0){
-      memmove(&p_out[k], &p_x[0], (size - k) * sizeof(int_fast64_t));
+      memmove(&p_out[k], &p_x[0], (size - k) * sizeof(int64_t));
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < k; ++i) p_out[i] = fill_value;
     } else {
-      memmove(&p_out[0], &p_x[-k], (size + k) * sizeof(int_fast64_t));
+      memmove(&p_out[0], &p_x[-k], (size + k) * sizeof(int64_t));
       OMP_FOR_SIMD
       for (R_xlen_t i = size - 1; i >= size + k; --i) p_out[i] = fill_value;
     }
@@ -283,20 +283,22 @@ SEXP lag(SEXP x, R_xlen_t k, SEXP fill, bool set) {
 
 [[cpp11::register]]
 SEXP cpp_lag(SEXP x, R_xlen_t k, SEXP fill, bool set, bool recursive){
+  int32_t NP = 0;
   SEXP out = R_NilValue;
   if (recursive && TYPEOF(x) == VECSXP){
     R_xlen_t size = Rf_xlength(x);
     const SEXP *p_x = VECTOR_PTR_RO(x);
-    out = SHIELD(new_vec(VECSXP, size));
+    out = SHIELD(new_vec(VECSXP, size)); ++NP;
     SHALLOW_DUPLICATE_ATTRIB(out, x);
     for (R_xlen_t i = 0; i < size; ++i){
       SET_VECTOR_ELT(out, i, cpp_lag(p_x[i], k, fill, set && !ALTREP(p_x[i]), true));
     }
   } else {
-    out = SHIELD(lag(x, k, fill, set));
-    set_names(out, lag(get_names(x), k, fill, set && !ALTREP(x)));
+    out = SHIELD(lag(x, k, fill, set)); ++NP;
+    SEXP names = SHIELD(get_names(x)); ++NP;
+    set_names(out, lag(names, k, fill, set && !ALTREP(x)));
   }
-  YIELD(1);
+  YIELD(NP);
   return out;
 }
 
@@ -305,7 +307,7 @@ SEXP lag2(SEXP x, SEXP lag, SEXP order, SEXP run_lengths, SEXP fill){
   int rl_size = Rf_length(run_lengths);
   int lag_size = Rf_length(lag);
   int fill_size = Rf_length(fill);
-  int NP = 0;
+  int32_t NP = 0;
   if (fill_size > 1){
     Rf_error("fill size must be NULL or length 1");
   }
@@ -406,14 +408,14 @@ SEXP lag2(SEXP x, SEXP lag, SEXP order, SEXP run_lengths, SEXP fill){
     if (has_order && (size != o_size)){
       Rf_error("length(order) must equal length(x) (%d)", size);
     }
-    const int_fast64_t *p_x = INTEGER64_PTR(x);
-    int_fast64_t fill_value = NA_INTEGER64;
+    const int64_t *p_x = INTEGER64_PTR(x);
+    int64_t fill_value = NA_INTEGER64;
     if (fill_size >= 1){
       SEXP temp_fill = SHIELD(coerce_vector(fill, CHEAPR_INT64SXP)); ++NP;
       fill_value = INTEGER64_PTR(temp_fill)[0];
     }
     out = SHIELD(cpp_semi_copy(x)); ++NP;
-    int_fast64_t* RESTRICT p_out = INTEGER64_PTR(out);
+    int64_t* RESTRICT p_out = INTEGER64_PTR(out);
     for (int i = 0; i != rl_size; ++i){
       run_start = run_end; // Start at the end of the previous run
       rl = has_rl ? p_rl[i] : size; // Current run-length
@@ -721,19 +723,21 @@ SEXP lag2(SEXP x, SEXP lag, SEXP order, SEXP run_lengths, SEXP fill){
 
 [[cpp11::register]]
 SEXP cpp_lag2(SEXP x, SEXP lag, SEXP order, SEXP run_lengths, SEXP fill, bool recursive){
+  int32_t NP = 0;
   SEXP out = R_NilValue;
   if (recursive && TYPEOF(x) == VECSXP){
     R_xlen_t size = Rf_xlength(x);
     const SEXP *p_x = VECTOR_PTR_RO(x);
-    out = SHIELD(new_vec(VECSXP, size));
+    out = SHIELD(new_vec(VECSXP, size)); ++NP;
     SHALLOW_DUPLICATE_ATTRIB(out, x);
     for (R_xlen_t i = 0; i < size; ++i){
       SET_VECTOR_ELT(out, i, cpp_lag2(p_x[i], lag, order, run_lengths, fill, true));
     }
   } else {
-    out = SHIELD(lag2(x, lag, order, run_lengths, fill));
-    set_names(out, lag2(get_names(x), lag, order, run_lengths, fill));
+    SEXP names = SHIELD(get_names(x)); ++NP;
+    out = SHIELD(lag2(x, lag, order, run_lengths, fill)); ++NP;
+    set_names(out, lag2(names, lag, order, run_lengths, fill));
   }
-  YIELD(1);
+  YIELD(NP);
   return out;
 }
